#ifndef H_CDW_COLORS
#define H_CDW_COLORS

#include "main.h"

/* see beginning of color.c for more details on these names and on
   use of cdw_colors_t type */
typedef enum {
	CDW_COLORS_MAIN = 1,
	CDW_COLORS_DIALOG,
	CDW_COLORS_TITLE,
	CDW_COLORS_MENU,
	CDW_COLORS_PROGRESS,
	CDW_COLORS_INPUT,
	CDW_COLORS_WARNING,
	CDW_COLORS_SIZE_INFO, /* unused, kept for compatibilty with older versions */
	CDW_COLORS_DISABLED,
	CDW_COLORS_UNUSED,
	CDW_COLORS_TOOLTIPS,
	CDW_COLORS_TEXTAREA,
	CDW_COLORS_ERROR, /* 13 */
	CDW_COLORS_GUARD /* this value is not used to create color scheme - this is a guard value */
} cdw_colors_t;



void     cdw_colors_init_phase1(void);
cdw_rv_t cdw_colors_init_phase2(void);

#endif /* #ifndef H_CDW_COLORS */
